==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Test/Gui/Resources/translations/Test_sr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="17"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="32"/>
      <source>Failures and errors</source>
      <translation>Кварови и грешке</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="48"/>
      <source>Description</source>
      <translation>Опис</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="83"/>
      <source>&amp;Start</source>
      <translation>&amp;Покрени</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="86"/>
      <source>Alt+S</source>
      <translation>Алт+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="115"/>
      <source>&amp;Help</source>
      <translation>&amp; Помоћ</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="118"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="128"/>
      <source>&amp;About</source>
      <translation>&amp;О</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="131"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="141"/>
      <source>&amp;Close</source>
      <translation>Zatvori</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="144"/>
      <source>Alt+C</source>
      <translation>Алт+Ц</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="162"/>
      <source>Idle</source>
      <translation>Неактиван</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="169"/>
      <source>Progress</source>
      <translation>Напредак</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="198"/>
      <source>Remaining:</source>
      <translation>Преостали:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="215"/>
      <source>Errors:</source>
      <translation>Грешке:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="232"/>
      <source>Failures:</source>
      <translation>Кварови:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="249"/>
      <source>Run:</source>
      <translation>Покретање:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="259"/>
      <source>Test</source>
      <translation>Тест</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="271"/>
      <source>Select test name:</source>
      <translation>Изаберите назив теста:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="152"/>
      <source>Help</source>
      <translation>Помоћ</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="152"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Упишите назив позовивог објекта који ће, када је позван, дати случај тестирања.
Кликните на „покрени“, и тест који производи биће покренут.

Два пута кликните на грешку у прегледу стаблом да видите више информација о њему, укључујући праћење спремника.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>About FreeCAD UnitTest</source>
      <translation>О FreeCAD UnitTest програму</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Ауторска права © Werner Mayer

„FreeCAD UnitTest“ је део FreeCAD-а и подржава писање тестирања јединице за њихове личне модуле.</translation>
    </message>
  </context>
</TS>

==> freecad_1.0.0+dfsg.orig.tar.xz: FreeCAD-1.0.0/src/Mod/Test/Gui/Resources/translations/Test_sr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="17"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="32"/>
      <source>Test</source>
      <translation>Тест</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="44"/>
      <source>Select test name:</source>
      <translation>Изаберите назив теста:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="96"/>
      <source>&amp;Start</source>
      <translation>&amp;Покрени</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="99"/>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="128"/>
      <source>&amp;Help</source>
      <translation>&amp;Помоћ</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="131"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="141"/>
      <source>&amp;About</source>
      <translation>&amp;О</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="144"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="154"/>
      <source>&amp;Close</source>
      <translation>&amp;Затвори</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="157"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="169"/>
      <source>Progress</source>
      <translation>Напредак</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="188"/>
      <source>Run:</source>
      <translation>Покрени:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="205"/>
      <source>Failures:</source>
      <translation>Кварови:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="222"/>
      <source>Errors:</source>
      <translation>Грешке:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="239"/>
      <source>Remaining:</source>
      <translation>Преостали:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="259"/>
      <source>Failures and errors</source>
      <translation>Кварови и грешке</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="275"/>
      <source>Description</source>
      <translation>Опис</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="292"/>
      <source>Idle</source>
      <translation>Неактиван</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="165"/>
      <source>Help</source>
      <translation>Помоћ</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="166"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Унеси име објекта који ће, када се позове, вратити ТестЦасе.
Кликни на 'старт' и тако произведен тест ц́е бити покренут.

Двапут кликни на грешку у стаблу документа да би видео више информација о њој, укључујући праћење стека.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="179"/>
      <source>About FreeCAD UnitTest</source>
      <translation>О FreeCAD UnitTest програму</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="180"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Ауторска права © Werner Mayer

FreeCAD UnitTest је део FreeCAD-а и подржава писање тестова за сопствене модуле.</translation>
    </message>
  </context>
</TS>
